/*
Copyright (C) 1997-2001 Id Software, Inc.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
/*
** QGL_WIN.C
**
** This file implements the operating system binding of GL to QGL function
** pointers.  When doing a port of Quake2 you must implement the following
** two functions:
**
** QGL_Init() - loads libraries, assigns function pointers, etc.
** QGL_Shutdown() - unloads libraries, NULLs function pointers
*/
#include <float.h>
#include "../ref_gl/gl_local.h"
#include "glw_win.h"

PFNGLLOCKARRAYSEXTPROC glLockArraysEXT;
PFNGLUNLOCKARRAYSEXTPROC glUnlockArraysEXT;

PFNWGLSWAPINTERVALEXTPROC wglSwapIntervalEXT;

PFNGLPOINTPARAMETERFEXTPROC glPointParameterfEXT;
PFNGLPOINTPARAMETERFVEXTPROC glPointParameterfvEXT;

PFNGLCOLORTABLEEXTPROC glColorTableEXT;

PFNGLMULTITEXCOORD2FSGISPROC glMultiTexCoord2fSGIS;
PFNGLSELECTTEXTURESGISPROC glSelectTextureSGIS;

PFNGLPNTRIANGLESIATIPROC glPNTrianglesiATI;

/*
** QGL_Shutdown
**
** Unloads the specified gl then nulls out all the proc pointers.
*/
void QGL_Shutdown( void )
{
	glLockArraysEXT = NULL;
	glUnlockArraysEXT = NULL;
	wglSwapIntervalEXT = NULL;
	glPointParameterfEXT = NULL;
	glPointParameterfvEXT = NULL;
	glColorTableEXT = NULL;
	glMultiTexCoord2fSGIS = NULL;
	glSelectTextureSGIS = NULL;
	glPNTrianglesiATI = NULL;
}

#	pragma warning (disable : 4113 4133 4047 )
#	define GPA( a ) wglGetProcAddress( a )

/*
** QGL_Init
**
** This is responsible for binding our qgl function pointers to 
** the appropriate GL stuff.  In Windows this means doing a 
** LoadLibrary and a bunch of calls to GetProcAddress.  On other
** operating systems we need to do the right thing, whatever that
** might be.
** 
*/
qboolean QGL_Init( void )
{
	// update 3Dfx gamma irrespective of underlying gl
	{
		char envbuffer[1024];
		float g;

		g = 2.00 * ( 0.8 - ( vid_gamma->value - 0.5 ) ) + 1.0F;
		Com_sprintf( envbuffer, sizeof(envbuffer), "SSTV2_GAMMA=%f", g );
		putenv( envbuffer );
		Com_sprintf( envbuffer, sizeof(envbuffer), "SST_GAMMA=%f", g );
		putenv( envbuffer );
	}

	gl_config.allow_cds = true;

	glLockArraysEXT = 0;
	glUnlockArraysEXT = 0;
	wglSwapIntervalEXT = 0;
	glPointParameterfEXT = 0;
	glPointParameterfvEXT = 0;
	glColorTableEXT = 0;
	glMultiTexCoord2fSGIS = 0;
	glSelectTextureSGIS = 0;
	glPNTrianglesiATI = 0;

	return true;
}

void GLimp_LogNewFrame( void )
{
	fprintf( glw_state.log_fp, "*** R_BeginFrame ***\n" );
}

#pragma warning (default : 4113 4133 4047 )
